@@ -8,13 +8,12 @@ hugging face
 from typing import Dict, List, Tuple
 
 import torch
+from biotransformers.lightning_utils.data import AlphabetDataLoader
+from biotransformers.utils.constant import DEFAULT_ROSTLAB_MODEL, ROSTLAB_LIST
 from biotransformers.wrappers.transformers_wrappers import TransformersWrapper
 from torch.nn import DataParallel
 from transformers import BertForMaskedLM, BertTokenizer
 
-rostlab_list = ["Rostlab/prot_bert", "Rostlab/prot_bert_bfd"]
-DEFAULT_MODEL = "Rostlab/prot_bert"
-
 
 class RostlabWrapper(TransformersWrapper):
     """
@@ -24,12 +23,12 @@ class RostlabWrapper(TransformersWrapper):
 
     def __init__(self, model_dir: str, device, multi_gpu):
 
-        if model_dir not in rostlab_list:
+        if model_dir not in ROSTLAB_LIST:
             print(
                 f"Model dir '{model_dir}' not recognized. "
-                f"Using '{DEFAULT_MODEL}' as default"
+                f"Using '{DEFAULT_ROSTLAB_MODEL}' as default"
             )
-            model_dir = DEFAULT_MODEL
+            model_dir = DEFAULT_ROSTLAB_MODEL
 
         super().__init__(model_dir, _device=device, multi_gpu=multi_gpu)
 
@@ -43,7 +42,6 @@ class RostlabWrapper(TransformersWrapper):
         self.hidden_size = self.model.config.hidden_size
         if self.multi_gpu:
             self.model = DataParallel(self.model)
-
         self.mask_pipeline = None
 
     @property
@@ -97,22 +95,19 @@ class RostlabWrapper(TransformersWrapper):
         return self.hidden_size
 
     def _process_sequences_and_tokens(
-        self, sequences_list: List[str], tokens_list: List[str]
-    ) -> Tuple[Dict[str, torch.tensor], torch.tensor, List[int]]:
+        self,
+        sequences_list: List[str],
+    ) -> Dict[str, torch.tensor]:
         """Function to transform tokens string to IDs; it depends on the model used"""
-        tokens = []
-        for token in tokens_list:
-            if token not in self.model_vocabulary:
-                print("Warnings; token", token, "does not belong to model vocabulary")
-            else:
-                tokens.append(self.token_to_id(token))
 
         separated_sequences_list = [" ".join(seq) for seq in sequences_list]
         encoded_inputs = self.tokenizer(
-            separated_sequences_list, return_tensors="pt", padding=True,
+            separated_sequences_list,
+            return_tensors="pt",
+            padding=True,
         ).to("cpu")
 
-        return encoded_inputs, encoded_inputs["input_ids"], tokens
+        return encoded_inputs
 
     def _model_pass(
         self, model_inputs: Dict[str, torch.tensor]
@@ -139,3 +134,25 @@ class RostlabWrapper(TransformersWrapper):
             embeddings = model_outputs.hidden_states[-1].detach().cpu()
 
         return logits, embeddings
+
+    def _get_alphabet_dataloader(self):
+        """Define an alphabet mapping for common method between
+        protbert and ESM
+        """
+
+        def tokenize(x: List[str]):
+            x_ = [" ".join(seq) for seq in x]
+            tokens = self.tokenizer(x_, return_tensors="pt", padding=True)
+            return x, tokens["input_ids"]
+
+        alphabet_dl = AlphabetDataLoader(
+            prepend_bos=True,
+            append_eos=True,
+            mask_idx=self.tokenizer.mask_token_id,
+            pad_idx=self.tokenizer.pad_token_id,
+            model_dir=self.model_dir,
+            lambda_toks_to_ids=lambda x: self.tokenizer.convert_tokens_to_ids(x),
+            lambda_tokenizer=lambda x: tokenize(x),
+        )
+
+        return alphabet_dl
